DiagnosticsEnumProperty class final

Inheritance

Constructors

DiagnosticsEnumProperty({required String name, required DiagnosticsLevel level, required String value, required String enumType})
const

Properties

enumType String
final
hashCode int
The hash code for this object.
no setteroverride
level DiagnosticsLevel
final
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
final

Methods

copyWith({String? name, DiagnosticsLevel? level, String? value, String? enumType}) DiagnosticsEnumProperty
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override